==> localnews-thirdparty-model-2.0.6-sources.jar: com/bxm/localnews/thirdparty/vo/Tools.java <==
package com.bxm.localnews.thirdparty.vo;

/**
 * @author zhaoyadong 2018/10/19 13:55
 * @desc
 */
public class Tools {

    private Long id;

    private String imgUrl;

    private String title;

    private Byte sensitiveFlag;

    private String url;

    private Byte status;

    private Long order;

    private Byte globalFlag;

    private Byte homeFlag;

    private String tooltip;

    private String areaCode;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getImgUrl() {
        return imgUrl;
    }

    public void setImgUrl(String imgUrl) {
        this.imgUrl = imgUrl;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public Byte getSensitiveFlag() {
        return sensitiveFlag;
    }

    public void setSensitiveFlag(Byte sensitiveFlag) {
        this.sensitiveFlag = sensitiveFlag;
    }

    public String getUrl() {
        return url;
    }

    public void setUrl(String url) {
        this.url = url;
    }

    public Byte getStatus() {
        return status;
    }

    public void setStatus(Byte status) {
        this.status = status;
    }

    public Long getOrder() {
        return order;
    }

    public void setOrder(Long order) {
        this.order = order;
    }

    public Byte getGlobalFlag() {
        return globalFlag;
    }

    public void setGlobalFlag(Byte globalFlag) {
        this.globalFlag = globalFlag;
    }

    public Byte getHomeFlag() {
        return homeFlag;
    }

    public void setHomeFlag(Byte homeFlag) {
        this.homeFlag = homeFlag;
    }

    public String getTooltip() {
        return tooltip;
    }

    public void setTooltip(String tooltip) {
        this.tooltip = tooltip;
    }

    public String getAreaCode() {
        return areaCode;
    }

    public void setAreaCode(String areaCode) {
        this.areaCode = areaCode;
    }

}

==> localnews-thirdparty-model-3.10.0-sources.jar: com/bxm/localnews/thirdparty/vo/Tools.java <==
package com.bxm.localnews.thirdparty.vo;

import com.bxm.localnews.common.dto.BaseDTO;

/**
 * @author zhaoyadong 2018/10/19 13:55
 * @desc
 */
public class Tools extends BaseDTO {

    private String imgUrl;

    private String title;

    private Byte sensitiveFlag;

    private String url;

    private Byte status;

    private Long order;

    private Byte homeFlag;

    private String tooltip;

    private String areaCode;

    public String getImgUrl() {
        return imgUrl;
    }

    public void setImgUrl(String imgUrl) {
        this.imgUrl = imgUrl;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public Byte getSensitiveFlag() {
        return sensitiveFlag;
    }

    public void setSensitiveFlag(Byte sensitiveFlag) {
        this.sensitiveFlag = sensitiveFlag;
    }

    public String getUrl() {
        return url;
    }

    public void setUrl(String url) {
        this.url = url;
    }

    public Byte getStatus() {
        return status;
    }

    public void setStatus(Byte status) {
        this.status = status;
    }

    public Long getOrder() {
        return order;
    }

    public void setOrder(Long order) {
        this.order = order;
    }

    public Byte getHomeFlag() {
        return homeFlag;
    }

    public void setHomeFlag(Byte homeFlag) {
        this.homeFlag = homeFlag;
    }

    public String getTooltip() {
        return tooltip;
    }

    public void setTooltip(String tooltip) {
        this.tooltip = tooltip;
    }

    public String getAreaCode() {
        return areaCode;
    }

    public void setAreaCode(String areaCode) {
        this.areaCode = areaCode;
    }

}
